# Pywalfox - Native messaging host

This is the source of the native application used by the Pywalfox Firefox add-on, providing access to your Pywal colors. It uses the [Native Messaging API](https://developer.mozilla.org/en-US/docs/Mozilla/Add-ons/WebExtensions/Native_messaging).

For more information, take a look at the [Pywalfox GitHub page](https://github.com/Frewacom/pywalfox).
